var group__utils =
[
    [ "Utilities to deal with Nucleotide Alphabets", "group__alphabet__utils.html", "group__alphabet__utils" ],
    [ "(Nucleic Acid Sequence) String Utilitites", "group__string__utils.html", "group__string__utils" ],
    [ "Secondary Structure Utilities", "group__struct__utils.html", "group__struct__utils" ],
    [ "Multiple Sequence Alignment Utilities", "group__aln__utils.html", "group__aln__utils" ],
    [ "Files and I/O", "group__file__utils.html", "group__file__utils" ],
    [ "Plotting", "group__plotting__utils.html", "group__plotting__utils" ],
    [ "Search Algorithms", "group__search__utils.html", "group__search__utils" ],
    [ "Combinatorics Algorithms", "group__combinatorics__utils.html", "group__combinatorics__utils" ],
    [ "(Abstract) Data Structures", "group__data__structures.html", "group__data__structures" ],
    [ "Messages", "group__message__utils.html", "group__message__utils" ],
    [ "Unit Conversion", "group__units.html", "group__units" ],
    [ "alphabet.h", "alphabet_8h.html", null ],
    [ "combinatorics.h", "combinatorics_8h.html", null ],
    [ "commands.h", "commands_8h.html", null ],
    [ "sequence.h", "sequence_8h.html", null ],
    [ "file_formats_msa.h", "io_2file__formats__msa_8h.html", null ],
    [ "utils.h", "io_2utils_8h.html", null ],
    [ "utils.h", "plotting_2utils_8h.html", null ],
    [ "alignments.h", "utils_2alignments_8h.html", null ],
    [ "basic.h", "utils_2basic_8h.html", null ],
    [ "strings.h", "strings_8h.html", null ],
    [ "units.h", "utils_2units_8h.html", null ],
    [ "BoyerMoore.h", "BoyerMoore_8h.html", null ],
    [ "char_stream.h", "datastructures_2char__stream_8h.html", null ],
    [ "stream_output.h", "datastructures_2stream__output_8h.html", null ],
    [ "VRNA_INPUT_ERROR", "group__utils.html#gad403c9ea58f1836689404c2931419c8c", null ],
    [ "VRNA_INPUT_QUIT", "group__utils.html#ga72f3c6ca5c83d2b9baed2922d19c403d", null ],
    [ "VRNA_INPUT_MISC", "group__utils.html#ga8e3241b321c9c1a78a69e59e2e019a71", null ],
    [ "VRNA_INPUT_FASTA_HEADER", "group__utils.html#ga2f0d8069e93d3ac54d9320d6bdb8e7e7", null ],
    [ "VRNA_INPUT_CONSTRAINT", "group__utils.html#gac08a9df45b9721b97a47dbfe7a6e5f85", null ],
    [ "VRNA_INPUT_NO_TRUNCATION", "group__utils.html#ga086742158293217a46ae2f71bb296937", null ],
    [ "VRNA_INPUT_NO_REST", "group__utils.html#ga7a2e8c50a0c7ce82e60da1016e1367fd", null ],
    [ "VRNA_INPUT_NO_SPAN", "group__utils.html#ga0de536599b881c787b0943a2671da476", null ],
    [ "VRNA_INPUT_NOSKIP_BLANK_LINES", "group__utils.html#gab4db885222b3b69608310d7c7e63e286", null ],
    [ "VRNA_INPUT_BLANK_LINE", "group__utils.html#ga305474b93ccb79ae4c7754016a8ddd84", null ],
    [ "VRNA_INPUT_NOSKIP_COMMENTS", "group__utils.html#ga0f6311f11bed1842e3a527ab27b294c6", null ],
    [ "VRNA_INPUT_COMMENT", "group__utils.html#gaf2062e0eeefffd3ed639af460b3d4fab", null ],
    [ "MIN2", "group__utils.html#gae0b9cd0ce090bd69b951aa73e8fa4f7d", null ],
    [ "MAX2", "group__utils.html#ga33297b3679c713b0c4d897cd0fe3b122", null ],
    [ "MIN3", "group__utils.html#ga721b8d5f3abef17f10293f1f7f8c958e", null ],
    [ "MAX3", "group__utils.html#ga8d577123d2e66d2b7d0bf9af6e172b93", null ],
    [ "vrna_alloc", "group__utils.html#gaf37a0979367c977edfb9da6614eebe99", null ],
    [ "vrna_realloc", "group__utils.html#ga27f4719a66c6f90d1cca3d1e6e696c6a", null ],
    [ "vrna_init_rand", "group__utils.html#ga0ad1f40ea316e5c5918695c35613027a", null ],
    [ "vrna_urn", "group__utils.html#ga384e256ebb295d04a14426179db0dd6e", null ],
    [ "vrna_int_urn", "group__utils.html#ga46111bb3747dbcf4609f0d40ae169ad9", null ],
    [ "vrna_time_stamp", "group__utils.html#gad3bbe8d01afb1310609cb018d5290550", null ],
    [ "get_input_line", "group__utils.html#ga8ef1835eb83f542396f59f0b205965e5", null ],
    [ "vrna_idx_row_wise", "group__utils.html#ga70b180e9ea764218a82647a1cd347445", null ],
    [ "vrna_idx_col_wise", "group__utils.html#ga89ebc69c52fa0c78c9e1974b0017746b", null ],
    [ "xsubi", "group__utils.html#gaf9a866c8417afda7368bbac939ab3c47", null ]
];